# Architecture Executive Dashboard
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#benefits)
  * [Executive KPIs](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#executive-kpis)
  * [Selecting Displayed KPIs](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#selecting-displayed-kpis)
  * [Configuring the Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#configuring-the-dashboard)
  * [Navigating the Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#navigating-the-dashboard)
  * [Permissions](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#permissions)
  * [Sharing Data with the Executive Team](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#sharing-data-with-the-executive-team)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard#best-practices)


The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.
